==> qtlockscreen_0.1.11.tar.gz: qtlockscreen-0.1.11/main.cpp <==
//    QtLockscreen
//    Copyright (C) 2011 Paolo Iommarini
//    sakya_tg@yahoo.it
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#include <QtGui/QApplication>
#include "lockscreen.h"
#include <QFile>
#include <QDir>
#include <QTranslator>
#include <iostream>

#define QUOTE_(x) #x
#define QUOTE(x) QUOTE_(x)

void SimpleLoggingHandler(QtMsgType type, const char *msg)
{
    if (!LockScreen::Debug)
        return;

    switch (type) {
        case QtDebugMsg:
            std::cout << "Debug: " << msg << std::endl;
            break;
        case QtCriticalMsg:
            std::cout  << "Critical: " << msg << std::endl;
            break;
        case QtWarningMsg:
            std::cout  << "Warning: " << msg << std::endl;
            break;
        case QtFatalMsg:
            std::cout  << "Fatal: " << msg << std::endl;
            abort();
    }
}

void printUsage()
{
    qDebug() << "Options:";
    qDebug() << " -c filename           : use filename as config file";
    qDebug() << " -s filename           : save a screenshot to filename and exit";
    qDebug() << " -d                    : debug mode";
}

int main(int argc, char *argv[])
{
    //QApplication::setGraphicsSystem("raster");
    QApplication a(argc, argv);
    a.setOrganizationName("sakya");
    a.setApplicationName("QtLockscreen");
    a.setApplicationVersion(QUOTE(APP_VERSION));
    qInstallMsgHandler(SimpleLoggingHandler);

    QSettings().setDefaultFormat(QSettings::IniFormat);
    QString name = QSettings().fileName();
    QFileInfo pathInfo(name);
    if (!QDir().exists(pathInfo.path()))
        QDir().mkpath(pathInfo.path());

    //Always copy the default current settings:
    QString def = QString("%1.default").arg(name);
    if (QFile::exists(def))
        QFile::remove(def);
    QFile::copy(":/DefaultSettings.conf", QString("%1.default").arg(name));

    //Copy the default settings if the file does not exists.
    if (!QFile::exists(name))
        QFile::copy(":/DefaultSettings.conf", name);

    QString screenshotFile;
    LockScreen::Settings = new QSettings();

#ifdef Q_WS_MAEMO_5
    LockScreen::Debug = false;

    for (int i=1; i<argc; i++){
        QString arg = argv[i];

        if (arg == "-h" || arg == "--help"){
            LockScreen::Debug = true;
            printUsage();
            return 0;
        }else if (arg == "-d")
            LockScreen::Debug = true;
        else if (arg == "-c" && argc > i + 1){
            QString file = argv[i+1];
            qDebug() << "Using config file:" << file;
            delete LockScreen::Settings;
            LockScreen::Settings = NULL;
            LockScreen::Settings = new QSettings(file, QSettings::IniFormat);
        } else if (arg == "-s" && argc > i + 1){
            LockScreen::Debug = true;
            screenshotFile = argv[i+1];
            qDebug() << "Saving screenshot to:" << screenshotFile;
            LockScreen::ScreenshotMode = true;
        }
    }
#else
    LockScreen::Debug = true;
#endif
    qDebug() << a.applicationName() << a.applicationVersion();
    qDebug() << "Copyright  2011 Paolo Iommarini";
    qDebug() << "sakya_tg@yahoo.it";

    //Translation:
    QString localeStr = LockScreen::Settings->value("Main/Locale", "").toString();
    if (!localeStr.isEmpty()){
        qDebug() << "Locale override:" << localeStr;
        QLocale l(localeStr);
        QLocale::setDefault(l);        
    }else
        localeStr = QLocale::system().name();
    qDebug() << "Locale:" << localeStr;
    QTranslator translator;
    if (translator.load(QString("/opt/qtlockscreen/qtlockscreen_%1").arg(localeStr)))
        a.installTranslator(&translator);

    LockScreen l;
    int res = 0;

    if (LockScreen::ScreenshotMode){
        l.saveScreenshot(screenshotFile);
        delete LockScreen::Settings;
    }else{
        if (LockScreen::Debug || LockScreen::isLocked())
            l.show();
        res = a.exec();
    }

    delete LockScreen::Settings;
    LockScreen::Settings = NULL;
    return res;
}

==> qtlockscreen_0.1.25.tar.gz: qtlockscreen-0.1.25/main.cpp <==
//    QtLockscreen
//    Copyright (C) 2011 Paolo Iommarini
//    sakya_tg@yahoo.it
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#include <QtGui/QApplication>
#include "lockscreen.h"
#include <QFile>
#include <QDir>
#include <QTranslator>
#include <iostream>

#define QUOTE_(x) #x
#define QUOTE(x) QUOTE_(x)

void SimpleLoggingHandler(QtMsgType type, const char *msg)
{
    if (!LockScreen::Debug)
        return;

    switch (type) {
        case QtDebugMsg:
            std::cout << "Debug: " << msg << std::endl;
            break;
        case QtCriticalMsg:
            std::cout  << "Critical: " << msg << std::endl;
            break;
        case QtWarningMsg:
            std::cout  << "Warning: " << msg << std::endl;
            break;
        case QtFatalMsg:
            std::cout  << "Fatal: " << msg << std::endl;
            abort();
    }
}

void printUsage()
{
    qDebug() << "Options:";
    qDebug() << " -c filename           : use filename as config file";
    qDebug() << " -s filename           : save a screenshot to filename and exit";
    qDebug() << " -d                    : debug mode";
}

int main(int argc, char *argv[])
{
    //QApplication::setGraphicsSystem("raster");
    QApplication a(argc, argv);
    a.setOrganizationName("sakya");
    a.setApplicationName("QtLockscreen");
    a.setApplicationVersion(QUOTE(APP_VERSION));
    qInstallMsgHandler(SimpleLoggingHandler);

    QSettings().setDefaultFormat(QSettings::IniFormat);
    QString name = QSettings().fileName();
    QFileInfo pathInfo(name);
    if (!QDir().exists(pathInfo.path()))
        QDir().mkpath(pathInfo.path());

    //Always copy the default current settings:
    QString def = QString("%1.default").arg(name);
    if (QFile::exists(def))
        QFile::remove(def);
    QFile::copy(":/default.ini", QString("%1.default").arg(name));

    //Copy the default settings if the file does not exists.
    if (!QFile::exists(name))
        QFile::copy(":/default.ini", name);

    QString screenshotFile;
    LockScreen::Settings = new QSettings();

#ifdef Q_WS_MAEMO_5
    LockScreen::Debug = false;

    for (int i=1; i<argc; i++){
        QString arg = argv[i];

        if (arg == "-h" || arg == "--help"){
            LockScreen::Debug = true;
            printUsage();
            return 0;
        }else if (arg == "-d")
            LockScreen::Debug = true;
        else if (arg == "-c" && argc > i + 1){
            QString file = argv[i+1];
            qDebug() << "Using config file:" << file;
            delete LockScreen::Settings;
            LockScreen::Settings = NULL;
            LockScreen::Settings = new QSettings(file, QSettings::IniFormat);
        } else if (arg == "-s" && argc > i + 1){
            LockScreen::Debug = true;
            screenshotFile = argv[i+1];
            qDebug() << "Saving screenshot to:" << screenshotFile;
            LockScreen::ScreenshotMode = true;
        }
    }
#else
    LockScreen::Debug = true;
#endif
    qDebug() << a.applicationName() << a.applicationVersion();
    qDebug() << "Copyright  2011 Paolo Iommarini";
    qDebug() << "sakya_tg@yahoo.it";

    //Translation:
    QString localeStr = LockScreen::Settings->value("Main/Locale", "").toString();
    if (!localeStr.isEmpty()){
        qDebug() << "Locale override:" << localeStr;
        QLocale l(localeStr);
        QLocale::setDefault(l);        
    }else
        localeStr = QLocale::system().name();
    qDebug() << "Locale:" << localeStr;
    QTranslator translator;
    if (translator.load(QString("/opt/qtlockscreen/qtlockscreen_%1").arg(localeStr)))
        a.installTranslator(&translator);

    LockScreen l;
    int res = 0;

    if (LockScreen::ScreenshotMode){
        l.saveScreenshot(screenshotFile);
        delete LockScreen::Settings;
    }else{
        if (LockScreen::Debug || LockScreen::isLocked())
            l.show();
        res = a.exec();
    }

    delete LockScreen::Settings;
    LockScreen::Settings = NULL;
    return res;
}
